@@ -32,9 +32,9 @@
 #include <kdebug.h>
 #include <kglobalaccel.h>
 
-#include <ntqnamespace.h>
-#include <ntqpainter.h>
-#include <ntqimage.h>
+#include <tqnamespace.h>
+#include <tqpainter.h>
+#include <tqimage.h>
 
 #include "kbconfig.h"
 #include "xkeyboard.h"
