@@ -42,9 +42,9 @@
 #include <kiconloader.h>
 #include <kdebug.h>
 #include <tdeversion.h>
-#include <ntqtooltip.h>
-#include <ntqstyle.h>
-#include <ntqpainter.h>
+#include <tqtooltip.h>
+#include <tqstyle.h>
+#include <tqpainter.h>
 
 #ifdef USE_BOLD_MENUITEM
 static TQColor getActiveTextColor(TDEPopupMenu *menu)
